#!/usr/bin/env python3

import requests
import time
import threading

from PIL import Image
from io import BytesIO

def download_thread():
    successfully_decoded = False
    try:
        while not successfully_decoded:
            print("Starting download...")

            r = requests.get('http://erlangen.leute.server.de/erlangenaktuell.jpg')
            bio = BytesIO(r.content)
            im = Image.open(bio)

            print("Download successful, image size: {}x{}".format(im.size[0], im.size[1]))

            print("Scaling down...")

            newwidth = 1200
            newsize = ( newwidth, int(im.size[1] * float(newwidth) / im.size[0]) )
            im_scaled = im.resize(newsize, Image.ANTIALIAS)

            outname = "webcam_" + time.strftime('unix%s-%Y%m%d-%H%M%S') + ".jpg"

            print("Saving image to {} ...".format(outname))

            im_scaled.save(outname, "JPEG", quality=85)

            successfully_decoded = True
            print("Done.")
    except Exception as e:
        print("An exception occured during image download, aborting.")
        print(e)


while True:
    t = threading.Thread(target=download_thread)
    t.start()
    time.sleep(60)
